@@ -1,9 +1,6 @@
 var dir_bd5473d7d5841d48919aaa9ad0cb1f9b =
 [
-    [ "array.h", "a00896.html", [
-      [ "ConstArray< TYPE >", "a01345.html", "a01345" ],
-      [ "Array< TYPE >", "a01349.html", "a01349" ]
-    ] ],
+    [ "array.h", "a00896.html", "a00896" ],
     [ "componentInterfaces.h", "a00884.html", null ],
     [ "fvarLevel.h", "a00881.html", null ],
     [ "fvarRefinement.h", "a00887.html", null ],
