@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "My Project", "index.html", [
+  [ "OpenSubdiv", "index.html", [
     [ "Namespaces", "namespaces.html", [
       [ "Namespace List", "namespaces.html", "namespaces_dup" ],
       [ "Namespace Members", "namespacemembers.html", [
@@ -42,7 +42,7 @@ var NAVTREE =
       [ "Class Members", "functions.html", [
         [ "All", "functions.html", "functions_dup" ],
         [ "Functions", "functions_func.html", "functions_func" ],
-        [ "Variables", "functions_vars.html", "functions_vars" ],
+        [ "Variables", "functions_vars.html", null ],
         [ "Typedefs", "functions_type.html", null ],
         [ "Enumerations", "functions_enum.html", null ],
         [ "Enumerator", "functions_eval.html", null ],
@@ -57,21 +57,18 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"a00551.html",
-"a00765.html",
-"a00789.html#ad2744ba943362370738d6bd8448cd779",
-"a00849.html#a232ddf5a15e24e91b2ec55f83a1436b5",
-"a00901.html#a34ad525bfe0752e223af5d175b73df4b",
-"a00937.html#a74b2f41060f4bc17f3522444d30126b6",
-"a00977.html#adb0788b75a061fc9b650d75bf691f1d8",
-"a01025.html#abce41960eb6bedc82cbf0cb711ea66da",
-"a01081.html#a01f08038160f2a7981d56c21a69c0eb9",
-"a01129.html#a590338ee8b544306b970a0c1445cd01f",
-"a01149.html#af9474cac29f3177edf5e8d72ea4a440c",
-"a01181.html#ace6e18c193c67b141335e056c636b508",
-"a01185.html#acf616c176f4307d0d8791b8622017d20",
-"a01205.html#a6aec03319164ba804dab193de6d70547",
-"a01320.html#aa3daa2f428c6be2b1cb394f3a525833da529a2651a5dcfac532e933ffefc36e99"
+"a00674.html",
+"a00912.html#a33f9830228f847fae1c30c9dffe02b5a",
+"a00957.html#aa7e32ce7ba896c5ddfe6521ad0022ce2",
+"a00993.html#a1d27edb01bfb68ba50776b25aa437783",
+"a01017.html#a19202138f911782b5652536867d24565",
+"a01069.html#aa71d36872f416feaa853788a7a7a7ef8",
+"a01113.html#ac5eadebfdd9b11ac383653e5a2383231",
+"a01161.html#a6a642b61f5cf7ced73523798467735a5",
+"a01205.html#ad9941ba7019b0fd8aad6e9321d91c26a",
+"a01261.html#a15628b18e19d90e91fdbd659925ae5c0",
+"a01301.html#a77cee40767fd4936f20a8f9d9d9ea625",
+"a01333.html#ab38c56ce6121aed94f2796bf5df894be"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
